/*************************************************************************
 *
 *
 *    (c) Copyright Olimex 2009
 *
 *    File name   : extcon_test.h
 *    Description : External connectors test
 *
 *    History :
 *    1. Date        : 10, November 2009
 *       Author      : Aleksandar Mitev
 *       Description : Create
 *
 **************************************************************************/

#ifndef _EXT_CON_TEST
#define _EXT_CON_TEST

#define EXT1 0x0
#define EXT2 0x1

typedef struct _PIN {
	GPIO_TypeDef *GPIO_Port;
	u8 GPIO_Pin;
	u8 EXT_Con;
	u8 EXT_Pin;
} PIN;

// definition of the used ports array
#define PORTS_USED(name) GPIO_TypeDef *name[] = \
	   { GPIOA, GPIOB, GPIOC, GPIOD, GPIOE }

// definition of the used ports enable bits
#define PORTS_ENABLE_BITS_USED(name) uint32_t name[] = \
	   { RCC_APB2Periph_GPIOA, RCC_APB2Periph_GPIOB, RCC_APB2Periph_GPIOC, RCC_APB2Periph_GPIOD, RCC_APB2Periph_GPIOE }

// definition of the main pin
#define MAIN_PIN(name) const PIN name = {GPIOD, 15, EXT1, 35}

// definition of port names
#define PORTS_NAMES(name) const char* name[] = \
	   { "GPIOA", "GPIOB", "GPIOC", "GPIOD", "GPIOE" }

// definition of external connectors names
#define EXT_CON_NAMES(name) const char* name[] = \
	   { "EXT1", "EXT2" }

// definition of the array of tested pins
#define PIN_MAP(name) const PIN name[] = { \
	   {GPIOA, 0, EXT1, 4}, \
	   {GPIOA, 1, EXT1, 5}, \
	   {GPIOA, 2, EXT1, 6}, \
	   {GPIOE, 8, EXT1, 7}, \
	   {GPIOE, 9, EXT1, 8}, \
	   {GPIOE, 10, EXT1, 9}, \
	   {GPIOE, 11, EXT1, 10}, \
	   {GPIOE, 12, EXT1, 11}, \
	   {GPIOE, 13, EXT1, 12}, \
	   {GPIOE, 14, EXT1, 13}, \
	   {GPIOE, 15, EXT1, 14}, \
	   {GPIOB, 0, EXT1, 15}, \
	   {GPIOB, 1, EXT1, 16}, \
	   {GPIOB, 5, EXT1, 17}, \
	   {GPIOB, 6, EXT1, 18}, \
	   {GPIOB, 7, EXT1, 19}, \
	   {GPIOB, 8, EXT1, 20}, \
	   {GPIOB, 9, EXT1, 21}, \
	   {GPIOB, 10, EXT1, 22}, \
	   {GPIOB, 11, EXT1, 23}, \
	   {GPIOB, 12, EXT1, 24}, \
	   {GPIOB, 13, EXT1, 25}, \
	   {GPIOB, 14, EXT1, 26}, \
	   {GPIOB, 15, EXT1, 27}, \
	   {GPIOD, 8, EXT1, 28}, \
	   {GPIOD, 9, EXT1, 29}, \
	   {GPIOD, 10, EXT1, 30}, \
	   {GPIOD, 11, EXT1, 31}, \
	   {GPIOD, 12, EXT1, 32}, \
	   {GPIOD, 13, EXT1, 33}, \
	   {GPIOD, 14, EXT1, 34}, \
	   {GPIOD, 0, EXT2, 4}, \
	   {GPIOD, 1, EXT2, 5}, \
	   {GPIOD, 2, EXT2, 6}, \
	   {GPIOD, 3, EXT2, 7}, \
	   {GPIOD, 4, EXT2, 8}, \
	   {GPIOD, 5, EXT2, 9}, \
	   {GPIOD, 6, EXT2, 10}, \
	   {GPIOC, 13, EXT2, 12}, \
	   {GPIOC, 12, EXT2, 13}, \
	   {GPIOC, 11, EXT2, 14}, \
	   {GPIOC, 10, EXT2, 15}, \
	   {GPIOC, 9, EXT2, 16}, \
	   {GPIOC, 8, EXT2, 17}, \
	   {GPIOC, 5, EXT2, 18}, \
	   {GPIOC, 4, EXT2, 19}, \
	   {GPIOC, 3, EXT2, 20}, \
	   {GPIOC, 2, EXT2, 21}, \
	   {GPIOC, 1, EXT2, 22}, \
	   {GPIOC, 0, EXT2, 23}, \
	   {GPIOA, 8, EXT2, 24}, \
	   {GPIOA, 7, EXT2, 25}, \
	   {GPIOA, 6, EXT2, 26}, \
	   {GPIOA, 5, EXT2, 27}, \
	   {GPIOA, 4, EXT2, 28}, \
	   {GPIOA, 3, EXT2, 29}, \
	   {GPIOE, 7, EXT2, 30}, \
	   {GPIOE, 6, EXT2, 31}, \
	   {GPIOE, 5, EXT2, 32}, \
	   {GPIOE, 4, EXT2, 33}, \
	   {GPIOE, 3, EXT2, 34}, \
	   {GPIOE, 2, EXT2, 35}, \
	   {GPIOE, 1, EXT2, 36}, \
	   {GPIOE, 0, EXT2, 37} \
}

int ExtConTest(void);

void ExtConMainPinDisable(void);
void ExtConMainPinEnable(void);

#endif // _EXT_CON_TEST



